About
=====

This is meant to provide a pedagogical Pythonic view of chi-feng's excellent
`mcmc-demo project`_, and also takes after `AM207`_.

Usage
-----

The package can be installed with ``pip install .`` or in development mode even ``python setup.py develop``.

.. code::

  python setup.py develop
  pytest

.. _`mcmc-demo project`: https://github.com/chi-feng/mcmc-demo/
.. _`AM207`: https://github.com/Paul-Yuchao-Dong/am207
